quantizationtools.JobHandler
============================

.. abjad-lineage:: abjad.tools.quantizationtools.JobHandler.JobHandler.JobHandler

.. autoclass:: abjad.tools.quantizationtools.JobHandler.JobHandler.JobHandler
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.JobHandler.JobHandler.JobHandler.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.JobHandler.JobHandler.JobHandler.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.JobHandler.JobHandler.JobHandler.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.JobHandler.JobHandler.JobHandler.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.JobHandler.JobHandler.JobHandler.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.JobHandler.JobHandler.JobHandler.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.JobHandler.JobHandler.JobHandler.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.JobHandler.JobHandler.JobHandler.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.JobHandler.JobHandler.JobHandler.__repr__
   :noindex:
